#include "base/base.h"
namespace mozc {
namespace {
class POSMatcher {
 public:
  // Functional "^(助詞|助動詞|動詞,非自立|名詞,非自立|形容詞,非自立|動詞,接尾|名詞,接尾|形容詞,接尾)"
  static uint16 GetFunctionalId() {
    return 42;
  }
  static bool IsFunctional(uint16 id) {
    return ((id >= 42 && id <= 542) || (id >= 1407 && id <= 2229) || (id >= 2309 && id <= 2332) || (id >= 2345 && id <= 2566) || (id >= 2860 && id <= 2972));
  }
  // Unknown "名詞,サ変接続"
  static uint16 GetUnknownId() {
    return 2230;
  }
  static bool IsUnknown(uint16 id) {
    return ((id >= 2230 && id <= 2233));
  }
  // FirstName "名詞,固有名詞,人名,名"
  static uint16 GetFirstNameId() {
    return 2299;
  }
  static bool IsFirstName(uint16 id) {
    return ((id == 2299));
  }
  // LastName "名詞,固有名詞,人名,姓"
  static uint16 GetLastNameId() {
    return 2300;
  }
  static bool IsLastName(uint16 id) {
    return ((id == 2300));
  }
  // Number "名詞,数,アラビア数字"
  static uint16 GetNumberId() {
    return 2335;
  }
  static bool IsNumber(uint16 id) {
    return ((id == 2335));
  }
  // KanjiNumber "名詞,数,漢数字"
  static uint16 GetKanjiNumberId() {
    return 2337;
  }
  static bool IsKanjiNumber(uint16 id) {
    return ((id >= 2337 && id <= 2343));
  }
  // WeakCompoundPrefix "^(接頭詞,名詞接続|フィラー)"
  static uint16 GetWeakCompoundPrefixId() {
    return 2;
  }
  static bool IsWeakCompoundPrefix(uint16 id) {
    return ((id >= 2 && id <= 11) || (id >= 2976 && id <= 2997));
  }
  // Prefix "接頭詞,"
  static uint16 GetPrefixId() {
    return 2975;
  }
  static bool IsPrefix(uint16 id) {
    return ((id >= 2975 && id <= 2999));
  }
  // JapanesePunctuations "記号,(句点|読点)"
  static uint16 GetJapanesePunctuationsId() {
    return 3002;
  }
  static bool IsJapanesePunctuations(uint16 id) {
    return ((id == 3002) || (id == 3005));
  }
  // OpenBracket "記号,括弧開"
  static uint16 GetOpenBracketId() {
    return 3004;
  }
  static bool IsOpenBracket(uint16 id) {
    return ((id == 3004));
  }
  // CloseBracket "記号,括弧閉"
  static uint16 GetCloseBracketId() {
    return 3003;
  }
  static bool IsCloseBracket(uint16 id) {
    return ((id == 3003));
  }
  // Zipcode "特殊,郵便番号"
  static uint16 GetZipcodeId() {
    return 3019;
  }
  static bool IsZipcode(uint16 id) {
    return ((id == 3019));
  }
  // IsolatedWord "特殊,短縮よみ"
  static uint16 GetIsolatedWordId() {
    return 3020;
  }
  static bool IsIsolatedWord(uint16 id) {
    return ((id == 3020));
  }
  // SuggestOnlyWord "特殊,サジェストのみ"
  static uint16 GetSuggestOnlyWordId() {
    return 3021;
  }
  static bool IsSuggestOnlyWord(uint16 id) {
    return ((id == 3021));
  }
 private:
  POSMatcher() {}
  ~POSMatcher() {}
};
}  // namespace
}  // mozc
